@@ -3,5 +3,5 @@
 
 #include "spvm_native.h"
 
-const char* FILE_NAME = "SPVM/Encode.c";
+static const char* FILE_NAME = "SPVM/Encode.c";
 
